/* Board */
#include "board.h"
#include "clock_config.h"
#include "pin_mux.h"

/* Debug Console */
#include "fsl_debug_console.h"

/* FreeRTOS */
#include "FreeRTOS.h"
#include "task.h"

/* App */
#include "app_sdmmc.h"

/* FreeRTOS heap placed into DTCM */
__attribute__((section(".freertos_heap"))) uint8_t ucHeap[configTOTAL_HEAP_SIZE];

static void init_task(void *parameters);

int main(void) {
    BOARD_ConfigMPU();
    BOARD_InitBootPins();
    BOARD_InitBootClocks();
    BOARD_InitDebugConsole();

    if (xTaskCreate(init_task, "INIT", 1024, NULL, 4, NULL) != pdPASS) {
        PRINTF("Failed to create init task.\r\n");

        goto dead_loop;
    }

    vTaskStartScheduler();

dead_loop:
    for (;;) {
        __WFI();
    }
}

static void init_task(void *parameters) {
    PRINTF("Initialization task running...\r\n");

    if (app_sdmmc_init() != 0) {
        PRINTF("Failed to initialize SDMMC.\r\n");
    }

    for (;;) {
        GPIO_PinWrite(BOARD_INITLEDPINS_IND_GPIO, BOARD_INITLEDPINS_IND_PIN, 0U);
        vTaskDelay(pdMS_TO_TICKS(500));
        GPIO_PinWrite(BOARD_INITLEDPINS_IND_GPIO, BOARD_INITLEDPINS_IND_PIN, 1U);
        vTaskDelay(pdMS_TO_TICKS(500));
    }

    vTaskDelete(NULL);
}